@@ -26,11 +26,12 @@ import types
 import os
 import json
 
-from unittest import *
-from unittest import _TextTestResult
+import unittest
 
-from cherrypy._cpcompat import basestring, ntob, py3k, HTTPConnection
-from cherrypy._cpcompat import HTTPSConnection, unicodestr
+import six
+
+from cherrypy._cpcompat import text_or_bytes, HTTPConnection
+from cherrypy._cpcompat import HTTPSConnection
 
 
 def interface(host):
@@ -40,14 +41,14 @@ def interface(host):
     or '::' (IN6ADDR_ANY), this will return the proper localhost."""
     if host == '0.0.0.0':
         # INADDR_ANY, which should respond on localhost.
-        return "127.0.0.1"
+        return '127.0.0.1'
     if host == '::':
         # IN6ADDR_ANY, which should respond on localhost.
-        return "::1"
+        return '::1'
     return host
 
 
-class TerseTestResult(_TextTestResult):
+class TerseTestResult(unittest._TextTestResult):
 
     def printErrors(self):
         # Overridden to avoid unnecessary empty line
@@ -58,7 +59,7 @@ class TerseTestResult(_TextTestResult):
             self.printErrorList('FAIL', self.failures)
 
 
-class TerseTestRunner(TextTestRunner):
+class TerseTestRunner(unittest.TextTestRunner):
 
     """A test runner class that displays results in textual form."""
 
@@ -66,25 +67,25 @@ class TerseTestRunner(TextTestRunner):
         return TerseTestResult(self.stream, self.descriptions, self.verbosity)
 
     def run(self, test):
-        "Run the given test case or test suite."
+        'Run the given test case or test suite.'
         # Overridden to remove unnecessary empty lines and separators
         result = self._makeResult()
         test(result)
         result.printErrors()
         if not result.wasSuccessful():
-            self.stream.write("FAILED (")
+            self.stream.write('FAILED (')
             failed, errored = list(map(len, (result.failures, result.errors)))
             if failed:
-                self.stream.write("failures=%d" % failed)
+                self.stream.write('failures=%d' % failed)
             if errored:
                 if failed:
-                    self.stream.write(", ")
-                self.stream.write("errors=%d" % errored)
-            self.stream.writeln(")")
+                    self.stream.write(', ')
+                self.stream.write('errors=%d' % errored)
+            self.stream.writeln(')')
         return result
 
 
-class ReloadingTestLoader(TestLoader):
+class ReloadingTestLoader(unittest.TestLoader):
 
     def loadTestsFromName(self, name, module=None):
         """Return a suite of all tests cases given a string specifier.
@@ -99,11 +100,11 @@ class ReloadingTestLoader(TestLoader):
         unused_parts = []
         if module is None:
             if not parts:
-                raise ValueError("incomplete test name: %s" % name)
+                raise ValueError('incomplete test name: %s' % name)
             else:
                 parts_copy = parts[:]
                 while parts_copy:
-                    target = ".".join(parts_copy)
+                    target = '.'.join(parts_copy)
                     if target in sys.modules:
                         module = reload(sys.modules[target])
                         parts = unused_parts
@@ -125,24 +126,24 @@ class ReloadingTestLoader(TestLoader):
 
         if isinstance(obj, types.ModuleType):
             return self.loadTestsFromModule(obj)
-        elif (((py3k and isinstance(obj, type))
+        elif (((six.PY3 and isinstance(obj, type))
                or isinstance(obj, (type, types.ClassType)))
-              and issubclass(obj, TestCase)):
+              and issubclass(obj, unittest.TestCase)):
             return self.loadTestsFromTestCase(obj)
         elif isinstance(obj, types.UnboundMethodType):
-            if py3k:
+            if six.PY3:
                 return obj.__self__.__class__(obj.__name__)
             else:
                 return obj.im_class(obj.__name__)
         elif hasattr(obj, '__call__'):
             test = obj()
-            if not isinstance(test, TestCase) and \
-               not isinstance(test, TestSuite):
-                raise ValueError("calling %s returned %s, "
-                                 "not a test" % (obj, test))
+            if not isinstance(test, unittest.TestCase) and \
+               not isinstance(test, unittest.TestSuite):
+                raise ValueError('calling %s returned %s, '
+                                 'not a test' % (obj, test))
             return test
         else:
-            raise ValueError("do not know how to make test from: %s" % obj)
+            raise ValueError('do not know how to make test from: %s' % obj)
 
 
 try:
@@ -176,8 +177,8 @@ except ImportError:
 # from jaraco.properties
 class NonDataProperty(object):
     def __init__(self, fget):
-        assert fget is not None, "fget cannot be none"
-        assert callable(fget), "fget must be callable"
+        assert fget is not None, 'fget cannot be none'
+        assert callable(fget), 'fget must be callable'
         self.fget = fget
 
     def __get__(self, obj, objtype=None):
@@ -186,13 +187,13 @@ class NonDataProperty(object):
         return self.fget(obj)
 
 
-class WebCase(TestCase):
-    HOST = "127.0.0.1"
+class WebCase(unittest.TestCase):
+    HOST = '127.0.0.1'
     PORT = 8000
     HTTP_CONN = HTTPConnection
-    PROTOCOL = "HTTP/1.1"
+    PROTOCOL = 'HTTP/1.1'
 
-    scheme = "http"
+    scheme = 'http'
     url = None
 
     status = None
@@ -205,7 +206,7 @@ class WebCase(TestCase):
 
     def get_conn(self, auto_open=False):
         """Return a connection to our HTTP server."""
-        if self.scheme == "https":
+        if self.scheme == 'https':
             cls = HTTPSConnection
         else:
             cls = HTTPConnection
@@ -233,13 +234,13 @@ class WebCase(TestCase):
         if on:
             self.HTTP_CONN = self.get_conn(auto_open=auto_open)
         else:
-            if self.scheme == "https":
+            if self.scheme == 'https':
                 self.HTTP_CONN = HTTPSConnection
             else:
                 self.HTTP_CONN = HTTPConnection
 
     def _get_persistent(self):
-        return hasattr(self.HTTP_CONN, "__class__")
+        return hasattr(self.HTTP_CONN, '__class__')
 
     def _set_persistent(self, on):
         self.set_persistent(on)
@@ -252,7 +253,7 @@ class WebCase(TestCase):
         or '::' (IN6ADDR_ANY), this will return the proper localhost."""
         return interface(self.HOST)
 
-    def getPage(self, url, headers=None, method="GET", body=None,
+    def getPage(self, url, headers=None, method='GET', body=None,
                 protocol=None, raise_subcls=None):
         """Open the url with debugging support. Return status, headers, body.
 
@@ -263,9 +264,9 @@ class WebCase(TestCase):
         """
         ServerError.on = False
 
-        if isinstance(url, unicodestr):
+        if isinstance(url, six.text_type):
             url = url.encode('utf-8')
-        if isinstance(body, unicodestr):
+        if isinstance(body, six.text_type):
             body = body.encode('utf-8')
 
         self.url = url
@@ -298,47 +299,47 @@ class WebCase(TestCase):
     console_height = 30
 
     def _handlewebError(self, msg):
-        print("")
-        print("    ERROR: %s" % msg)
+        print('')
+        print('    ERROR: %s' % msg)
 
         if not self.interactive:
             raise self.failureException(msg)
 
-        p = ("    Show: "
-             "[B]ody [H]eaders [S]tatus [U]RL; "
-             "[I]gnore, [R]aise, or sys.e[X]it >> ")
+        p = ('    Show: '
+             '[B]ody [H]eaders [S]tatus [U]RL; '
+             '[I]gnore, [R]aise, or sys.e[X]it >> ')
         sys.stdout.write(p)
         sys.stdout.flush()
         while True:
             i = getchar().upper()
-            if not isinstance(i, type("")):
+            if not isinstance(i, type('')):
                 i = i.decode('ascii')
-            if i not in "BHSUIRX":
+            if i not in 'BHSUIRX':
                 continue
             print(i.upper())  # Also prints new line
-            if i == "B":
+            if i == 'B':
                 for x, line in enumerate(self.body.splitlines()):
                     if (x + 1) % self.console_height == 0:
                         # The \r and comma should make the next line overwrite
-                        sys.stdout.write("<-- More -->\r")
+                        sys.stdout.write('<-- More -->\r')
                         m = getchar().lower()
                         # Erase our "More" prompt
-                        sys.stdout.write("            \r")
-                        if m == "q":
+                        sys.stdout.write('            \r')
+                        if m == 'q':
                             break
                     print(line)
-            elif i == "H":
+            elif i == 'H':
                 pprint.pprint(self.headers)
-            elif i == "S":
+            elif i == 'S':
                 print(self.status)
-            elif i == "U":
+            elif i == 'U':
                 print(self.url)
-            elif i == "I":
+            elif i == 'I':
                 # return without raising the normal exception
                 return
-            elif i == "R":
+            elif i == 'R':
                 raise self.failureException(msg)
-            elif i == "X":
+            elif i == 'X':
                 self.exit()
             sys.stdout.write(p)
             sys.stdout.flush()
@@ -348,7 +349,7 @@ class WebCase(TestCase):
 
     def assertStatus(self, status, msg=None):
         """Fail if self.status != status."""
-        if isinstance(status, basestring):
+        if isinstance(status, text_or_bytes):
             if not self.status == status:
                 if msg is None:
                     msg = 'Status (%r) != %r' % (self.status, status)
@@ -363,7 +364,7 @@ class WebCase(TestCase):
             # status is a tuple or list.
             match = False
             for s in status:
-                if isinstance(s, basestring):
+                if isinstance(s, text_or_bytes):
                     if self.status == s:
                         match = True
                         break
@@ -411,7 +412,7 @@ class WebCase(TestCase):
             return value
 
         if msg is None:
-            msg = "%r not in %r" % (value, header_values)
+            msg = '%r not in %r' % (value, header_values)
         self._handlewebError(msg)
 
     def assertNoHeader(self, key, msg=None):
@@ -425,7 +426,7 @@ class WebCase(TestCase):
 
     def assertBody(self, value, msg=None):
         """Fail if value != self.body."""
-        if isinstance(value, unicodestr):
+        if isinstance(value, six.text_type):
             value = value.encode(self.encoding)
         if value != self.body:
             if msg is None:
@@ -435,7 +436,7 @@ class WebCase(TestCase):
 
     def assertInBody(self, value, msg=None):
         """Fail if value not in self.body."""
-        if isinstance(value, unicodestr):
+        if isinstance(value, six.text_type):
             value = value.encode(self.encoding)
         if value not in self.body:
             if msg is None:
@@ -444,7 +445,7 @@ class WebCase(TestCase):
 
     def assertNotInBody(self, value, msg=None):
         """Fail if value in self.body."""
-        if isinstance(value, unicodestr):
+        if isinstance(value, six.text_type):
             value = value.encode(self.encoding)
         if value in self.body:
             if msg is None:
@@ -453,7 +454,7 @@ class WebCase(TestCase):
 
     def assertMatchesBody(self, pattern, msg=None, flags=0):
         """Fail if value (a regex pattern) is not in self.body."""
-        if isinstance(pattern, unicodestr):
+        if isinstance(pattern, six.text_type):
             pattern = pattern.encode(self.encoding)
         if re.search(pattern, self.body, flags) is None:
             if msg is None:
@@ -461,7 +462,7 @@ class WebCase(TestCase):
             self._handlewebError(msg)
 
 
-methods_with_bodies = ("POST", "PUT")
+methods_with_bodies = ('POST', 'PUT')
 
 
 def cleanHeaders(headers, method, body, host, port):
@@ -478,9 +479,9 @@ def cleanHeaders(headers, method, body, host, port):
             break
     if not found:
         if port == 80:
-            headers.append(("Host", host))
+            headers.append(('Host', host))
         else:
-            headers.append(("Host", "%s:%s" % (host, port)))
+            headers.append(('Host', '%s:%s' % (host, port)))
 
     if method in methods_with_bodies:
         # Stick in default type and length headers if not present
@@ -491,38 +492,38 @@ def cleanHeaders(headers, method, body, host, port):
                 break
         if not found:
             headers.append(
-                ("Content-Type", "application/x-www-form-urlencoded"))
-            headers.append(("Content-Length", str(len(body or ""))))
+                ('Content-Type', 'application/x-www-form-urlencoded'))
+            headers.append(('Content-Length', str(len(body or ''))))
 
     return headers
 
 
 def shb(response):
     """Return status, headers, body the way we like from a response."""
-    if py3k:
+    if six.PY3:
         h = response.getheaders()
     else:
         h = []
         key, value = None, None
         for line in response.msg.headers:
             if line:
-                if line[0] in " \t":
+                if line[0] in ' \t':
                     value += line.strip()
                 else:
                     if key and value:
                         h.append((key, value))
-                    key, value = line.split(":", 1)
+                    key, value = line.split(':', 1)
                     key = key.strip()
                     value = value.strip()
         if key and value:
             h.append((key, value))
 
-    return "%s %s" % (response.status, response.reason), h, response.read()
+    return '%s %s' % (response.status, response.reason), h, response.read()
 
 
-def openURL(url, headers=None, method="GET", body=None,
-            host="127.0.0.1", port=8000, http_conn=HTTPConnection,
-            protocol="HTTP/1.1", raise_subcls=None):
+def openURL(url, headers=None, method='GET', body=None,
+            host='127.0.0.1', port=8000, http_conn=HTTPConnection,
+            protocol='HTTP/1.1', raise_subcls=None):
     """
     Open the given HTTP resource and return status, headers, and body.
 
@@ -538,21 +539,21 @@ def openURL(url, headers=None, method="GET", body=None,
     for trial in range(10):
         try:
             # Allow http_conn to be a class or an instance
-            if hasattr(http_conn, "host"):
+            if hasattr(http_conn, 'host'):
                 conn = http_conn
             else:
                 conn = http_conn(interface(host), port)
 
             conn._http_vsn_str = protocol
-            conn._http_vsn = int("".join([x for x in protocol if x.isdigit()]))
+            conn._http_vsn = int(''.join([x for x in protocol if x.isdigit()]))
 
-            if py3k and isinstance(url, bytes):
+            if six.PY3 and isinstance(url, bytes):
                 url = url.decode()
             conn.putrequest(method.upper(), url, skip_host=True,
                             skip_accept_encoding=True)
 
             for key, value in headers:
-                conn.putheader(key, value.encode("Latin-1"))
+                conn.putheader(key, value.encode('Latin-1'))
             conn.endheaders()
 
             if body is not None:
@@ -563,7 +564,7 @@ def openURL(url, headers=None, method="GET", body=None,
 
             s, h, b = shb(response)
 
-            if not hasattr(http_conn, "host"):
+            if not hasattr(http_conn, 'host'):
                 # We made our own conn instance. Close it.
                 conn.close()
 
@@ -606,6 +607,6 @@ def server_error(exc=None):
         return False
     else:
         ServerError.on = True
-        print("")
-        print("".join(traceback.format_exception(*exc)))
+        print('')
+        print(''.join(traceback.format_exception(*exc)))
         return True
